@@ -438,6 +438,7 @@ duckhts_extension_dir <- function() {
 #' @param table_name Name for the created table
 #' @param path Path to the VCF/BCF file
 #' @param region Optional genomic region (e.g., "chr1:1000-2000")
+#' @param index_path Optional explicit path to index file (.csi/.tbi)
 #' @param tidy_format Logical. If TRUE, FORMAT columns are returned in tidy format
 #' @param overwrite Logical. If TRUE, overwrites existing table
 #'
@@ -460,6 +461,7 @@ rduckhts_bcf <- function(
   table_name,
   path,
   region = NULL,
+  index_path = NULL,
   tidy_format = FALSE,
   overwrite = FALSE
 ) {
@@ -481,6 +483,9 @@ rduckhts_bcf <- function(
   if (!is.null(region)) {
     params$region <- sprintf("'%s'", region)
   }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
   if (tidy_format) {
     params$tidy_format <- "true"
   }
@@ -514,6 +519,7 @@ rduckhts_bcf <- function(
 #' @param table_name Name for the created table
 #' @param path Path to the SAM/BAM/CRAM file
 #' @param region Optional genomic region (e.g., "chr1:1000-2000")
+#' @param index_path Optional explicit path to index file (.bai/.csi/.crai)
 #' @param reference Optional reference file path for CRAM files
 #' @param standard_tags Logical. If TRUE, include typed standard SAMtags columns
 #' @param auxiliary_tags Logical. If TRUE, include AUXILIARY_TAGS map of non-standard tags
@@ -538,6 +544,7 @@ rduckhts_bam <- function(
   table_name,
   path,
   region = NULL,
+  index_path = NULL,
   reference = NULL,
   standard_tags = NULL,
   auxiliary_tags = NULL,
@@ -560,6 +567,9 @@ rduckhts_bam <- function(
   if (!is.null(region)) {
     params$region <- sprintf("'%s'", region)
   }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
   if (!is.null(reference)) {
     params$reference <- sprintf("'%s'", reference)
   }
@@ -658,12 +668,21 @@ normalize_tabix_types <- function(types) {
 #' @param con A DuckDB connection with DuckHTS loaded
 #' @param table_name Name for the created table
 #' @param path Path to the FASTA file
+#' @param region Optional genomic region (e.g., "chr1:1000-2000" or "chr1:1-10,chr2:5-20")
+#' @param index_path Optional explicit path to FASTA index file (.fai)
 #' @param overwrite Logical. If TRUE, overwrites existing table
 #'
 #' @return Invisible TRUE on success
 #'
 #' @export
-rduckhts_fasta <- function(con, table_name, path, overwrite = FALSE) {
+rduckhts_fasta <- function(
+  con,
+  table_name,
+  path,
+  region = NULL,
+  index_path = NULL,
+  overwrite = FALSE
+) {
   if (!missing(table_name) && !is.null(table_name)) {
     if (DBI::dbExistsTable(con, table_name) && !overwrite) {
       stop(
@@ -677,16 +696,27 @@ rduckhts_fasta <- function(con, table_name, path, overwrite = FALSE) {
     }
   }
 
+  params <- list()
+  if (!is.null(region)) {
+    params$region <- sprintf("'%s'", region)
+  }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
+  param_str <- build_param_str(params)
+
   if (!is.null(table_name)) {
     create_query <- sprintf(
-      "CREATE TABLE %s AS SELECT * FROM read_fasta('%s')",
+      "CREATE TABLE %s AS SELECT * FROM read_fasta('%s'%s)",
       table_name,
-      path
+      path,
+      param_str
     )
   } else {
     create_query <- sprintf(
-      "CREATE VIEW fasta_data AS SELECT * FROM read_fasta('%s')",
-      path
+      "CREATE VIEW fasta_data AS SELECT * FROM read_fasta('%s'%s)",
+      path,
+      param_str
     )
   }
 
@@ -694,6 +724,31 @@ rduckhts_fasta <- function(con, table_name, path, overwrite = FALSE) {
   invisible(TRUE)
 }
 
+#' Build FASTA Index
+#'
+#' Builds a FASTA index (.fai) using the DuckHTS extension.
+#'
+#' @param con A DuckDB connection with DuckHTS loaded
+#' @param path Path to the FASTA file
+#' @param index_path Optional explicit output path for FASTA index file (.fai)
+#'
+#' @return A data frame with columns `success` and `index_path`
+#'
+#' @export
+rduckhts_fasta_index <- function(con, path, index_path = NULL) {
+  params <- list()
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
+  param_str <- build_param_str(params)
+  query <- sprintf(
+    "SELECT * FROM fasta_index('%s'%s)",
+    path,
+    param_str
+  )
+  DBI::dbGetQuery(con, query)
+}
+
 #' Create FASTQ Table
 #'
 #' Creates a DuckDB table from FASTQ files using the DuckHTS extension.
@@ -894,6 +949,7 @@ rduckhts_gtf <- function(
 #' @param table_name Name for the created table
 #' @param path Path to the tabix-indexed file
 #' @param region Optional genomic region (e.g., "chr1:1000-2000")
+#' @param index_path Optional explicit path to index file (.tbi/.csi)
 #' @param header Logical. If TRUE, use first non-meta line as column names
 #' @param header_names Character vector to override column names
 #' @param auto_detect Logical. If TRUE, infer basic numeric column types
@@ -908,6 +964,7 @@ rduckhts_tabix <- function(
   table_name,
   path,
   region = NULL,
+  index_path = NULL,
   header = NULL,
   header_names = NULL,
   auto_detect = NULL,
@@ -931,6 +988,9 @@ rduckhts_tabix <- function(
   if (!is.null(region)) {
     params$region <- sprintf("'%s'", region)
   }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
   if (!is.null(header)) {
     params$header <- if (isTRUE(header)) "true" else "false"
   }
@@ -977,3 +1037,103 @@ rduckhts_tabix <- function(
   DBI::dbExecute(con, create_query)
   invisible(TRUE)
 }
+
+#' Read HTS Header Metadata
+#'
+#' Reads file header records from HTS-supported formats using the DuckHTS extension.
+#'
+#' @param con A DuckDB connection with DuckHTS loaded
+#' @param path Path to input HTS file
+#' @param format Optional format hint (e.g., "auto", "vcf", "bcf", "bam", "cram", "tabix")
+#' @param mode Header output mode: "parsed" (default), "raw", or "both"
+#'
+#' @return A data frame with parsed header metadata.
+#'
+#' @export
+rduckhts_hts_header <- function(con, path, format = NULL, mode = NULL) {
+  params <- list()
+  if (!is.null(format)) {
+    params$format <- sprintf("'%s'", format)
+  }
+  if (!is.null(mode)) {
+    params$mode <- sprintf("'%s'", mode)
+  }
+  param_str <- build_param_str(params)
+  query <- sprintf("SELECT * FROM read_hts_header('%s'%s)", path, param_str)
+  DBI::dbGetQuery(con, query)
+}
+
+#' Read HTS Index Metadata
+#'
+#' Reads index metadata from HTS-supported index files via DuckHTS.
+#'
+#' @param con A DuckDB connection with DuckHTS loaded
+#' @param path Path to input HTS file
+#' @param format Optional format hint (e.g., "auto", "vcf", "bcf", "bam", "cram", "tabix")
+#' @param index_path Optional explicit path to index file
+#'
+#' @return A data frame with index metadata.
+#'
+#' @export
+rduckhts_hts_index <- function(con, path, format = NULL, index_path = NULL) {
+  params <- list()
+  if (!is.null(format)) {
+    params$format <- sprintf("'%s'", format)
+  }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
+  param_str <- build_param_str(params)
+  query <- sprintf("SELECT * FROM read_hts_index('%s'%s)", path, param_str)
+  DBI::dbGetQuery(con, query)
+}
+
+#' Read HTS Index Spans
+#'
+#' Returns index span-oriented metadata for planning range workloads.
+#'
+#' @param con A DuckDB connection with DuckHTS loaded
+#' @param path Path to input HTS file
+#' @param format Optional format hint
+#' @param index_path Optional explicit path to index file
+#'
+#' @return A data frame with span-oriented index metadata.
+#'
+#' @export
+rduckhts_hts_index_spans <- function(con, path, format = NULL, index_path = NULL) {
+  params <- list()
+  if (!is.null(format)) {
+    params$format <- sprintf("'%s'", format)
+  }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
+  param_str <- build_param_str(params)
+  query <- sprintf("SELECT * FROM read_hts_index_spans('%s'%s)", path, param_str)
+  DBI::dbGetQuery(con, query)
+}
+
+#' Read Raw HTS Index Blob
+#'
+#' Returns raw index metadata blob data for a file index.
+#'
+#' @param con A DuckDB connection with DuckHTS loaded
+#' @param path Path to input HTS file
+#' @param format Optional format hint
+#' @param index_path Optional explicit path to index file
+#'
+#' @return A data frame with raw index blob metadata.
+#'
+#' @export
+rduckhts_hts_index_raw <- function(con, path, format = NULL, index_path = NULL) {
+  params <- list()
+  if (!is.null(format)) {
+    params$format <- sprintf("'%s'", format)
+  }
+  if (!is.null(index_path)) {
+    params$index_path <- sprintf("'%s'", index_path)
+  }
+  param_str <- build_param_str(params)
+  query <- sprintf("SELECT * FROM read_hts_index_raw('%s'%s)", path, param_str)
+  DBI::dbGetQuery(con, query)
+}
